package com.songhua.web.controller.system;

import com.songhua.common.annotation.Log;
import com.songhua.common.core.controller.BaseController;
import com.songhua.common.core.domain.AjaxResult;
import com.songhua.common.core.page.TableDataInfo;
import com.songhua.common.enums.BusinessType;
import com.songhua.common.utils.poi.ExcelUtil;
import com.songhua.system.domain.PzRawData;
import com.songhua.system.domain.PzRawDataVo;
import com.songhua.system.service.IPzRawDataService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 原始数据导入Controller
 *
 * @author ruoyi
 * @date 2024-11-04
 */
@RestController
@RequestMapping("/system/data")
public class PzRawDataController extends BaseController {
    @Autowired
    private IPzRawDataService pzRawDataService;

    /**
     * 查询原始数据导入列表
     */
    @PreAuthorize("@ss.hasPermi('system:data:list')")
    @GetMapping("/list")
    public TableDataInfo list(PzRawData pzRawData) {
        startPage();
        List<PzRawDataVo> list = pzRawDataService.selectPzRawDataList(pzRawData);
        return getDataTable(list);
    }


    /**
     * 导入原始数据列表
     */
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception {
        ExcelUtil<PzRawDataVo> util = new ExcelUtil<PzRawDataVo>(PzRawDataVo.class);
        List<PzRawDataVo> userList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = pzRawDataService.importData(userList, updateSupport, operName);
        return success(message);
    }

    /**
     * 导入模板
     */
    @ApiOperation(value = "导入模板", notes = "导入模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) {
        ExcelUtil<PzRawData> util = new ExcelUtil<>(PzRawData.class);
        util.importTemplateExcel(response, "票务原始数据");
    }

    /**
     * 获取原始数据导入详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:data:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(pzRawDataService.selectPzRawDataById(id));
    }

    /**
     * 新增原始数据导入
     */
    @PreAuthorize("@ss.hasPermi('system:data:add')")
    @Log(title = "原始数据导入", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PzRawData pzRawData) {
        return toAjax(pzRawDataService.insertPzRawData(pzRawData));
    }

    /**
     * 修改原始数据导入
     */
    @PreAuthorize("@ss.hasPermi('system:data:edit')")
    @Log(title = "原始数据导入", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PzRawData pzRawData) {
        return toAjax(pzRawDataService.updatePzRawData(pzRawData));
    }

    /**
     * 删除原始数据导入
     */
    @PreAuthorize("@ss.hasPermi('system:data:remove')")
    @Log(title = "原始数据导入", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(pzRawDataService.deletePzRawDataByIds(ids));
    }


    /**
     * 导出原始数据导入列表
     */
    @Log(title = "导出原始数据导入列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public AjaxResult export(PzRawData pzRawData) {
        pzRawDataService.export(pzRawData);
        return AjaxResult.success();
    }
}
